@@ -7,7 +7,7 @@ use warnings;
 use autodie;
 use namespace::autoclean;
 
-our $VERSION = '0.54';
+our $VERSION = '0.55';
 
 use Dist::Zilla;
 
@@ -349,7 +349,7 @@ sub _build_exclude {
             push @filenames, $exclude;
         }
         else {
-            push @match, $exclude;
+            push @match, qr/$exclude/;
         }
     }
 
@@ -709,7 +709,7 @@ Dist::Zilla::PluginBundle::DROLSKY - DROLSKY's plugin bundle
 
 =head1 VERSION
 
-version 0.54
+version 0.55
 
 =head1 DESCRIPTION
 
